==> hyades.source_3.0.2_20050225_1641.zip: org/eclipse/hyades/log/ui/internal/navigator/LogNavigatorActionGroup.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
/*
 * Created on Nov 3, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package org.eclipse.hyades.log.ui.internal.navigator;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.log.ui.internal.actions.SaveAction;
import org.eclipse.hyades.models.hierarchy.CorrelationContainerProxy;
import org.eclipse.hyades.models.hierarchy.TRCAgentProxy;
import org.eclipse.hyades.models.hierarchy.TRCNode;
import org.eclipse.hyades.models.hierarchy.TRCProcessProxy;
import org.eclipse.hyades.trace.internal.ui.TraceConstants;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.hyades.trace.ui.internal.actions.TraceLogActionGroup;
import org.eclipse.hyades.ui.extension.INavigatorContribution;
import org.eclipse.hyades.ui.extension.INavigatorItem;
import org.eclipse.hyades.ui.internal.logicalfolder.LogicalFolder;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.actions.ActionContext;
import org.eclipse.ui.actions.OpenFileAction;

/**
 * @author apnan
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class LogNavigatorActionGroup extends TraceLogActionGroup {

	private OpenFileAction fOpenFileAction;
	private NewActionGroup newActionGroup;
	private SaveAction fLogNavigatorSaveAction;
	
	/**
	 * Constructor for LogNavigatorActionGroup
	 * @param logNavigator
	 */
	public LogNavigatorActionGroup(LogNavigator logNavigator)
	{
		super(logNavigator);
	}

	
	/**
	 * @see org.eclipse.ui.actions.ActionGroup#dispose()
	 */
	public void dispose()
	{
		newActionGroup.dispose();
		newActionGroup = null;
		fOpenFileAction = null;
		super.dispose();
		
	}

	/**
	 * @see org.eclipse.ui.actions.ActionGroup#setContext(org.eclipse.ui.actions.ActionContext)
	 */
	public void setContext(ActionContext context)
	{
		if(newActionGroup!=null)
			newActionGroup.setContext(context);
		
		super.setContext(context);
		
	}


	/**
	 * @see org.eclipse.ui.actions.ActionGroup#fillContextMenu(org.eclipse.jface.action.IMenuManager)
	 */
	public void fillContextMenu(IMenuManager menu)
	{
		super.fillContextMenu(menu);
		
		newActionGroup.fillContextMenu(menu);
		IStructuredSelection selection = (IStructuredSelection)getContext().getSelection();
		boolean sameClass = false;
		boolean multiSelection = (selection.size() > 1);
		if (multiSelection)
			sameClass = areSameClass(selection);
		
		Object sel = null;
		if(selection.iterator().hasNext()){
			sel = selection.iterator().next();
		}

		updateActions(selection);
		
		if(sel!=null){
			if (sel instanceof LogicalFolder)
			{				
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);

			}else if(sel instanceof TRCAgentProxy)
			{
						
				if (!multiSelection || sameClass) {
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fMonitorGrp);
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fGCGroup);
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fAttachGrp);				
					
				}
				
				if(!multiSelection)
				{
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fNewSnapshotGrp);				
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fTerminateGrp);
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, new Separator(GROUP_ADD_VIEWS));		
					addViews(menu, sel);
				}

				menu.appendToGroup(INavigatorContribution.GROUP_DELETE,fDeleteAction);
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);
		    	
			}else if(sel instanceof CorrelationContainerProxy){
				if(!multiSelection)
				{
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, new Separator(GROUP_ADD_VIEWS));		
					addViews(menu, sel);
				}

				menu.appendToGroup(INavigatorContribution.GROUP_DELETE,fDeleteAction);
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);
			
			}
			else if(sel instanceof IFile){
				menu.appendToGroup(INavigatorContribution.GROUP_OPEN, fOpenFileAction);
				fOpenFileAction.selectionChanged((IStructuredSelection)getContext().getSelection());
				menu.appendToGroup(INavigatorContribution.GROUP_DELETE,fDeleteAction);
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);
			
			}else if(sel instanceof TRCNode){				
				menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, new Separator(GROUP_ADD_VIEWS));			
				addViews(menu, sel); 
				menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fRefreshGrp);			
			}
			else if (sel instanceof INavigatorItem) {
				menu.appendToGroup(INavigatorContribution.GROUP_DELETE, fDeleteAction);
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE, fLogNavigatorSaveAction);
				menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, new Separator(GROUP_ADD_VIEWS));			
				addViews(menu, sel); 
				menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fRefreshGrp);			
			}
		}
	
		menu.appendToGroup(INavigatorContribution.GROUP_REFRESH,fRefreshTree);
		menu.appendToGroup(INavigatorContribution.GROUP_REFRESH,fRefreshLocal);

		if (!multiSelection) {
			
			if (sel instanceof TRCAgentProxy) {
				if (((TRCAgentProxy) sel).getType().equals(TraceConstants.LOG_AGENT_TYPE)) {
					menu.appendToGroup(INavigatorContribution.GROUP_PROPERTIES,fOpenLogAgentAction);
				}
			}else if (sel instanceof TRCNode) {
				menu.appendToGroup(INavigatorContribution.GROUP_PROPERTIES,fOpenNodeAction);
			}	
		}

		fImportActionGroup.fillContextMenu(menu);
	}
	
	/**
	 * Insert the method's description here.
	 * Creation date: (08/24/2000 2:06:10 PM)
	 * @param menu com.ibm.jface.MenuManager
	 */
	protected void addViews(IMenuManager menu, Object obj) {
		
		if(obj == null || !((obj instanceof EObject) || (obj instanceof INavigatorItem)))
		  return;

		MenuManager popup = new MenuManager(UIPlugin.getResourceString("MENU_MANAGER"));
		menu.appendToGroup(GROUP_ADD_VIEWS,popup);
		  
		if(obj instanceof TRCAgentProxy)
		{
			IAction[] actions = getViewMappingForType(((TRCAgentProxy)obj).getType());
			for(int idx=0; idx<actions.length; idx++)
			{
				if(actions[idx] != null)
				   popup.add(actions[idx]);
			}
		}else if(obj instanceof CorrelationContainerProxy){
			IAction[] actions = getViewMappingForType(TraceConstants.LOG_AGENT_TYPE);
			for(int idx=0; idx<actions.length; idx++)
			{
				if(actions[idx] != null)
				   popup.add(actions[idx]);
			}
			
		}else if(obj instanceof TRCNode)
		{
			IAction[] actions = getViewMappingForType(TraceConstants.HOST_TYPE);
			for(int idx=0; idx<actions.length; idx++)
			{
				if(actions[idx] != null)
				   popup.add(actions[idx]);
			}
			
			List typesList = new ArrayList();
			List processes = ((TRCNode) obj).getProcessProxies();
			for(int i=0; i<processes.size(); i++)
			{
				TRCProcessProxy process = (TRCProcessProxy)processes.get(i);
				List agents = process.getAgentProxies();
				
				for(int j=0; j<agents.size(); j++)
				{
					TRCAgentProxy agent = (TRCAgentProxy)agents.get(j);
					
					if(typesList.contains(agent.getType()))
					  continue; //actions already added to the popup
					
					typesList.add(agent.getType());
					actions = getViewMappingForType(agent.getType());
					if(actions.length > 0)
					{//add the actions to the popup
						popup.add(new Separator());						
						for(int k=0; k<actions.length; k++)
							popup.add(actions[k]);
					}
				}
			}
			
		}
		else if (obj instanceof INavigatorItem)
		{
			IAction[] actions = getViewMappingForType(((INavigatorItem)obj).getType());
			for(int idx=0; idx<actions.length; idx++)
			{
				if(actions[idx] != null)
				   popup.add(actions[idx]);
			}
		}
	}
	
	
		
	/**
	 * @see org.eclipse.ui.actions.ActionGroup#fillActionBars(org.eclipse.ui.IActionBars)
	 */
	public void fillActionBars(IActionBars actionBars)
	{		
		if(newActionGroup!=null){
			newActionGroup.fillActionBars(actionBars);
		}
		super.fillActionBars(actionBars);		
	}
	
	/**
	 * @see org.eclipse.hyades.ui.internal.navigator.action.NavigatorActionGroup#handleKeyPressed(org.eclipse.swt.events.KeyEvent)
	 */
	public void handleKeyPressed(KeyEvent event)
	{

		super.handleKeyPressed(event);
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.ui.internal.navigator.action.NavigatorActionGroup#createActions()
	 */
	protected void createActions() {		
		super.createActions();
		fOpenFileAction = new OpenFileAction(getNavigator().getSite().getPage());
		fLogNavigatorSaveAction = new SaveAction(getNavigator());
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.ui.internal.navigator.action.NavigatorActionGroup#createActionGroups()
	 */
	protected void createActionGroups() {
		super.createActionGroups();
		newActionGroup = new NewActionGroup((LogNavigator)getNavigator());
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.trace.ui.internal.actions.TraceLogActionGroup#handleDoubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
	 */
	public void handleDoubleClick(DoubleClickEvent event) {
		super.handleDoubleClick(event);
		IStructuredSelection s = (IStructuredSelection) event.getSelection();
		Object obj = s.getFirstElement();
		if(obj instanceof IFile){
			fOpenFileAction.selectionChanged(s);
			fOpenFileAction.run();	
		}		
	}

}

==> hyades.source_3.1.0_20041019_1201.zip: org/eclipse/hyades/log/ui/internal/navigator/LogNavigatorActionGroup.java <==
/**********************************************************************
 * Copyright (c) 2003 Hyades project.
 * All rights reserved.   This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * IBM - Initial API and implementation
 **********************************************************************/
/*
 * Created on Nov 3, 2003
 *
 * To change the template for this generated file go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
package org.eclipse.hyades.log.ui.internal.navigator;

import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.eclipse.core.resources.IFile;
import org.eclipse.emf.ecore.EObject;
import org.eclipse.hyades.log.ui.internal.actions.SaveAction;
import org.eclipse.hyades.models.hierarchy.CorrelationContainerProxy;
import org.eclipse.hyades.models.hierarchy.TRCAgentProxy;
import org.eclipse.hyades.models.hierarchy.TRCNode;
import org.eclipse.hyades.models.hierarchy.TRCProcessProxy;
import org.eclipse.hyades.trace.internal.ui.TraceConstants;
import org.eclipse.hyades.trace.ui.HyadesUtil;
import org.eclipse.hyades.trace.ui.UIPlugin;
import org.eclipse.hyades.trace.ui.internal.actions.TraceLogActionGroup;
import org.eclipse.hyades.ui.extension.INavigatorContribution;
import org.eclipse.hyades.ui.extension.INavigatorItem;
import org.eclipse.hyades.ui.internal.logicalfolder.LogicalFolder;
import org.eclipse.hyades.ui.internal.navigator.INavigator;
import org.eclipse.jface.action.IAction;
import org.eclipse.jface.action.IMenuManager;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.action.Separator;
import org.eclipse.jface.viewers.DoubleClickEvent;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.KeyEvent;
import org.eclipse.ui.IActionBars;
import org.eclipse.ui.actions.ActionContext;
import org.eclipse.ui.actions.OpenFileAction;

/**
 * @author apnan
 *
 * To change the template for this generated type comment go to
 * Window&gt;Preferences&gt;Java&gt;Code Generation&gt;Code and Comments
 */
public class LogNavigatorActionGroup extends TraceLogActionGroup {

	private OpenFileAction fOpenFileAction;
	private NewActionGroup newActionGroup;
	private SaveAction fLogNavigatorSaveAction;
		
	/**
	 * Constructor for LogNavigatorActionGroup
	 * @param logNavigator
	 */
	public LogNavigatorActionGroup(LogNavigator logNavigator)
	{
		super(logNavigator);
	}

	
	/**
	 * @see org.eclipse.ui.actions.ActionGroup#dispose()
	 */
	public void dispose()
	{
		newActionGroup.dispose();
		newActionGroup = null;
		fOpenFileAction = null;
		super.dispose();
		
	}

	/**
	 * @see org.eclipse.ui.actions.ActionGroup#setContext(org.eclipse.ui.actions.ActionContext)
	 */
	public void setContext(ActionContext context)
	{	
		if(newActionGroup!=null)
			newActionGroup.setContext(context);
		
		super.setContext(context);
		
	}


	/**
	 * @see org.eclipse.ui.actions.ActionGroup#fillContextMenu(org.eclipse.jface.action.IMenuManager)
	 */
	public void fillContextMenu(IMenuManager menu)
	{
		super.fillContextMenu(menu);			
		
		newActionGroup.fillContextMenu(menu);
		IStructuredSelection selection = (IStructuredSelection)getContext().getSelection();
		boolean sameClass = false;	
		boolean multiSelection = (selection.size() > 1);
		if (multiSelection)
			sameClass = areSameClass(selection);
		
		Object sel = null;
		if(selection.iterator().hasNext()){
			sel = selection.iterator().next();		
		} 
			
		updateActions(selection);	
				
		if(sel!=null){			
			if (sel instanceof LogicalFolder)
			{	
				/* bug 32375
				 * LOGIC of single selection :
				 * if folder is not empty, then append Save action to the popup menu,
				 * if folder is empty, then don't append Save action to the popup menu.
				 * */
				if(!multiSelection){ 
				  if ( ((LogicalFolder)sel).hasChildren() ) 
					menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);
				}
				
				/* bug 32375
				 * LOGIC of multiple selection :
				 * if one of folders is not empty, then append Save action to the popup menu,
				 * if all folders is empty, then don't append Save action to the popup menu.
				 * */
				if(multiSelection ){ 
					Object sel2 = null;
					boolean ifAppendSaveAction = false;
					Iterator i = selection.iterator();
					while(i.hasNext()){
						sel2 = i.next();								       
						if(sel2 instanceof LogicalFolder) {
					        if(((LogicalFolder)sel2).hasChildren()){
					        	ifAppendSaveAction = true;
					        	break;
					        }
						}			          
					}
					
					if(ifAppendSaveAction==true){
						menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);
					}
				}							
			}else if(sel instanceof TRCAgentProxy) 
			{	
							
				if (!multiSelection || sameClass) {
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fMonitorGrp);
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fGCGroup);
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fAttachGrp);				
			
				}
				
				if(!multiSelection)
				{
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fNewSnapshotGrp);				
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fTerminateGrp);
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, new Separator(GROUP_ADD_VIEWS));		
					addViews(menu, sel);
				}

				menu.appendToGroup(INavigatorContribution.GROUP_DELETE,fDeleteAction);
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);
		    	
			}else if(sel instanceof CorrelationContainerProxy){
				if(!multiSelection)
				{
					menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, new Separator(GROUP_ADD_VIEWS));		
					addViews(menu, sel);
				}

				menu.appendToGroup(INavigatorContribution.GROUP_DELETE,fDeleteAction);
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);
			
			}
			else if(sel instanceof IFile){
				menu.appendToGroup(INavigatorContribution.GROUP_OPEN, fOpenFileAction);
				fOpenFileAction.selectionChanged((IStructuredSelection)getContext().getSelection());
				menu.appendToGroup(INavigatorContribution.GROUP_DELETE,fDeleteAction);
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE,fLogNavigatorSaveAction);
			
			}else if(sel instanceof TRCNode){				
				menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, new Separator(GROUP_ADD_VIEWS));			
				addViews(menu, sel); 
				menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fRefreshGrp);			
			}
			else if (sel instanceof INavigatorItem) {
				menu.appendToGroup(INavigatorContribution.GROUP_DELETE, fDeleteAction);
				menu.appendToGroup(INavigatorContribution.GROUP_SAVE, fLogNavigatorSaveAction);
				menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, new Separator(GROUP_ADD_VIEWS));			
				addViews(menu, sel); 
				menu.appendToGroup(INavigatorContribution.GROUP_ADDITIONS, fRefreshGrp);			
			}
		}
				
		menu.appendToGroup(INavigatorContribution.GROUP_REFRESH,fRefreshTree);
		menu.appendToGroup(INavigatorContribution.GROUP_REFRESH,fRefreshLocal);

		if (!multiSelection) {
			
			if (sel instanceof TRCAgentProxy) {
				if (((TRCAgentProxy) sel).getType().equals(TraceConstants.LOG_AGENT_TYPE)) {
					menu.appendToGroup(INavigatorContribution.GROUP_PROPERTIES,fOpenLogAgentAction);
				}
			}else if (sel instanceof TRCNode) {
				menu.appendToGroup(INavigatorContribution.GROUP_PROPERTIES,fOpenNodeAction);
			}	
		}

		fImportActionGroup.fillContextMenu(menu);
	}
	
	/**
	 * Insert the method's description here.
	 * Creation date: (08/24/2000 2:06:10 PM)
	 * @param menu com.ibm.jface.MenuManager
	 */
	protected void addViews(IMenuManager menu, Object obj) {
		
		if(obj == null || !((obj instanceof EObject) || (obj instanceof INavigatorItem)))
		  return;

		MenuManager popup = new MenuManager(UIPlugin.getResourceString("MENU_MANAGER"));
		menu.appendToGroup(GROUP_ADD_VIEWS,popup);
		  
		if(obj instanceof TRCAgentProxy)
		{
			IAction[] actions = getViewMappingForType(((TRCAgentProxy)obj).getType());
			for(int idx=0; idx<actions.length; idx++)
			{
				if(actions[idx] != null)
				   popup.add(actions[idx]);
			}
		}else if(obj instanceof CorrelationContainerProxy){
			IAction[] actions = getViewMappingForType(TraceConstants.LOG_AGENT_TYPE);
			for(int idx=0; idx<actions.length; idx++)
			{
				if(actions[idx] != null)
				   popup.add(actions[idx]);
			}
			
		}else if(obj instanceof TRCNode)
		{
			IAction[] actions = getViewMappingForType(TraceConstants.HOST_TYPE);
			for(int idx=0; idx<actions.length; idx++)
			{
				if(actions[idx] != null)
				   popup.add(actions[idx]);
			}
			
			List typesList = new ArrayList();
			List processes = ((TRCNode) obj).getProcessProxies();
			for(int i=0; i<processes.size(); i++)
			{
				TRCProcessProxy process = (TRCProcessProxy)processes.get(i);
				List agents = process.getAgentProxies();
				
				for(int j=0; j<agents.size(); j++)
				{
					TRCAgentProxy agent = (TRCAgentProxy)agents.get(j);
					
					if(typesList.contains(agent.getType()))
					  continue; //actions already added to the popup
					
					typesList.add(agent.getType());
					actions = getViewMappingForType(agent.getType());
					if(actions.length > 0)
					{//add the actions to the popup
						popup.add(new Separator());						
						for(int k=0; k<actions.length; k++)
							popup.add(actions[k]);
					}
				}
			}
			
		}
		else if (obj instanceof INavigatorItem)
		{
			IAction[] actions = getViewMappingForType(((INavigatorItem)obj).getType());
			for(int idx=0; idx<actions.length; idx++)
			{
				if(actions[idx] != null)
				   popup.add(actions[idx]);
			}
		}
	}
	
	
		
	/**
	 * @see org.eclipse.ui.actions.ActionGroup#fillActionBars(org.eclipse.ui.IActionBars)
	 */
	public void fillActionBars(IActionBars actionBars)
	{		
		if(newActionGroup!=null){
			newActionGroup.fillActionBars(actionBars);
		}
		super.fillActionBars(actionBars);		
	}
	
	/* (non-Javadoc)
	 * @see org.eclipse.hyades.ui.internal.navigator.action.NavigatorActionGroup#createActions()
	 */
	protected void createActions() {		
		super.createActions();
		fOpenFileAction = new OpenFileAction(getNavigator().getSite().getPage());
		fLogNavigatorSaveAction = new SaveAction(getNavigator());
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.ui.internal.navigator.action.NavigatorActionGroup#createActionGroups()
	 */
	protected void createActionGroups() {
		super.createActionGroups();
		newActionGroup = new NewActionGroup((LogNavigator)getNavigator());
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.trace.ui.internal.actions.TraceLogActionGroup#handleDoubleClick(org.eclipse.jface.viewers.DoubleClickEvent)
	 */
	public void handleDoubleClick(DoubleClickEvent event) {
		super.handleDoubleClick(event);
		IStructuredSelection s = (IStructuredSelection) event.getSelection();
		Object obj = s.getFirstElement();
		if(obj instanceof IFile){
			fOpenFileAction.selectionChanged(s);
			fOpenFileAction.run();	
		}		
	}

	/* (non-Javadoc)
	 * @see org.eclipse.hyades.ui.internal.navigator.action.NavigatorActionGroup#handleKeyPressed(org.eclipse.swt.events.KeyEvent)
	 */
	public void handleKeyPressed(KeyEvent event) {
		if(event.character == SWT.DEL && (event.stateMask == 0)) {
			INavigator navigator = HyadesUtil.getActiveNavigator();
			IStructuredSelection selection = navigator.getStructuredSelection();
			updateActions(selection);
			Iterator iter = selection.iterator();
			while (iter.hasNext()) {
				if (iter.next() instanceof LogicalFolder) {
					fDeleteAction.setEnabled(false);
				}
			}
			if(fDeleteAction.isEnabled()) {
				fDeleteAction.run();
			}
		}
	}
}
